@@ -1,6 +1,8 @@
 """Do the migration
 """
-import logging, os, sys, shutil
+import logging, os, sys, shutil, urllib2
+
+BOOTSTRAP_URL = 'http://svn.zope.org/*checkout*/zc.buildout/trunk/bootstrap/bootstrap.py'
 
 
 logger = logging.getLogger('migrator')
@@ -25,13 +27,15 @@ def main():
         return
     os.mkdir(mig_dir)
     src_dir = os.path.dirname(__file__)
+    buildout_cfg = os.path.join(src_dir, 'buildout.cfg')
+    shutil.copy(buildout_cfg, mig_dir)
     scripts_dir = os.path.join(src_dir, 'scripts')
     mig_scripts_dir = os.path.join(mig_dir, 'scripts')
     shutil.copytree(scripts_dir, mig_scripts_dir)
     templates_dir = os.path.join(src_dir, 'templates')
-    for f1 in os.listdir(templates_dir):
-        src_file = os.path.join(templates_dir, f1)
-        shutil.copy(src_file, mig_dir)
+    mig_templates_dir = os.path.join(mig_dir, 'templates')
+    shutil.copytree(templates_dir, mig_templates_dir)
     os.chdir(mig_dir)
-    os.system('buildout bootstrap')
+    ez = {}
+    exec urllib2.urlopen(BOOTSTRAP_URL).read() in ez
     os.system('bin/buildout')
